
International Components for Unicode
------------------------------------

https://github.com/unicode-org/icu/blob/main/icu4c/source/data/mappings/


>This is the repository for the International Components for Unicode. The ICU project is under the stewardship of The Unicode Consortium.
